@@ -2,8 +2,6 @@
 
 from typing import Final, List
 
-from . import data_types
-
 WLAN_ENCRYPTION_UNKNOWN: Final = 0
 WLAN_ENCRYPTION_NONE: Final = 1
 WLAN_ENCRYPTION_WEP: Final = 2
@@ -20,12 +18,12 @@ WLAN_ENCRYPTION: Final = (
 DEFAULT_IP: Final = "0.0.0.0"
 DEFAULT_NETMASK: Final = "255.255.255.0"
 
-MODULE_PANEL: Final = "module_panel"
 MODULE_A: Final = "module_a"
 MODULE_B: Final = "module_b"
 MODULE_C: Final = "module_c"
 MODULE_LAMBDA: Final = "module_lambda"
 MODULE_ECOSTER: Final = "module_ecoster"
+MODULE_PANEL: Final = "module_panel"
 MODULES: Final = (
     MODULE_A,
     MODULE_B,
@@ -35,16 +33,6 @@ MODULES: Final = (
     MODULE_PANEL,
 )
 
-MODES: Final = (
-    "Off",
-    "Starting",
-    "Kindling",
-    "Heating",
-    "Supervision",
-    "Cooling",
-    "Standby",
-)
-
 MIXER_TEMP: Final = "temp"
 MIXER_TARGET: Final = "target"
 MIXER_PUMP: Final = "pump"
@@ -299,9 +287,10 @@ DEVICE_PARAMS: Final = (
     "buffer_histeresis",
     "buffer_load_start",
     "buffer_load_stop",
-    "boiler_control",
 )
 
+PARAM_BOILER_CONTROL: Final = "boiler_control"
+
 MIXER_PARAMS: Final = (
     "mix_set_temp",
     "min_mix_set_temp",
@@ -319,26 +308,6 @@ MIXER_PARAMS: Final = (
     "mix_summer_work",
 )
 
-DATA_TYPES: Final = (
-    data_types.Undefined0,
-    data_types.SignedChar,
-    data_types.Short,
-    data_types.Int,
-    data_types.Byte,
-    data_types.UnsignedShort,
-    data_types.UnsignedInt,
-    data_types.Float,
-    data_types.Undefined8,
-    data_types.Double,
-    data_types.Boolean,
-    data_types.String,
-    data_types.String,
-    data_types.Int64,
-    data_types.UInt64,
-    data_types.IPv4,
-    data_types.IPv6,
-)
-
 REGDATA_SCHEMA: Final = {
     1792: DATA_MODE,
     1024: TEMPERATURES[0],
