@@ -8,8 +8,8 @@ from .constants import (
     DATA_MODE,
     DEVICE_DATA,
     DEVICE_PARAMS,
-    MODES,
     MODULE_A,
+    PARAM_BOILER_CONTROL,
 )
 from .frame import Request
 from .helpers.base_device import BaseDevice
@@ -20,6 +20,23 @@ from .storage import FrameBucket
 ECOMAX_ADDRESS: Final = 0x45
 ECOSTER_ADDRESS: Final = 0x51
 
+MODE_OFF: Final = 0
+MODE_KINDLING: Final = 1
+MODE_FANNING: Final = 2
+MODE_HEATING: Final = 3
+MODE_SUSTAIN: Final = 4
+MODE_IDLE: Final = 5
+MODE_STANDBY: Final = 6
+MODES: Final = (
+    "Off",
+    "Kindling",
+    "Fanning",
+    "Heating",
+    "Sustain",
+    "Idle",
+    "Standby",
+)
+
 
 class Device(BaseDevice):
     """Device representation.
@@ -30,8 +47,7 @@ class Device(BaseDevice):
         product -- device product type
         uid -- device uid string
         password -- device service password
-        struct -- device regdata schema
-        _is_on -- is device currently turned on
+        schema -- device regdata schema
     """
 
     def __init__(
@@ -48,21 +64,37 @@ class Device(BaseDevice):
         self.__dict__["product"] = None
         self.__dict__["uid"] = None
         self.__dict__["password"] = None
-        self.__dict__["struct"] = []
-        self.__dict__["_is_on"] = False
+        self.__dict__["schema"] = []
         super().__init__(data, parameters)
 
+    def __str__(self) -> str:
+        """Converts device instance to a string."""
+        return f"""
+Product:        {self.product}
+Software Ver.:  {self.software}
+UID:            {self.uid}
+Password:       {self.password}
+
+{super().__str__()}
+
+Mixers:
+{self.mixers}
+""".strip()
+
     def set_data(self, data: Dict[str, Any]) -> None:
         """Sets device data.
 
         Keyword arguments:
             data -- immutable device attributes
         """
-        self.bucket.fill(data[DATA_FRAMES])
         for name, value in data.items():
             if name in DEVICE_DATA:
                 self._data[name] = value
 
+        self._set_boiler_control_parameter()
+        if DATA_FRAMES in data:
+            self.bucket.fill(data[DATA_FRAMES])
+
     def set_parameters(self, parameters: Dict[str, List[int]]) -> None:
         """Sets device parameters.
 
@@ -73,13 +105,16 @@ class Device(BaseDevice):
             if name in DEVICE_PARAMS:
                 self._parameters[name] = Parameter(name, *parameter)
 
-        self._parameters["boiler_control"] = Parameter(
-            name="boiler_control", value=int(self.is_on), min_=0, max_=1
-        )
-
-    def has_mixers(self) -> bool:
-        """Check if device instance has mixers."""
-        return bool(self.mixers.mixers)
+    def _set_boiler_control_parameter(self):
+        """Sets boiler control parameter from device data."""
+        if PARAM_BOILER_CONTROL in self._parameters and isinstance(
+            self._parameters[PARAM_BOILER_CONTROL], Parameter
+        ):
+            self._parameters[PARAM_BOILER_CONTROL].value = int(self.is_on)
+        else:
+            self._parameters[PARAM_BOILER_CONTROL] = Parameter(
+                name=PARAM_BOILER_CONTROL, value=int(self.is_on), min_=0, max_=1
+            )
 
     @property
     def software(self) -> Optional[str]:
@@ -93,19 +128,15 @@ class Device(BaseDevice):
     def is_on(self) -> bool:
         """Returns current state."""
         if DATA_MODE in self._data:
-            return bool(self._data[DATA_MODE] != 0)
+            return self._data[DATA_MODE] != MODE_OFF
 
         return False
 
     @property
     def mode(self) -> str:
         """Returns current mode."""
-        if self._data:
-            mode = self._data[DATA_MODE]
-            try:
-                return MODES[mode]
-            except IndexError:
-                pass
+        if DATA_MODE in self._data and self._data[DATA_MODE] < len(MODES):
+            return MODES[self._data[DATA_MODE]]
 
         return "Unknown"
 
@@ -122,20 +153,6 @@ class Device(BaseDevice):
         """Returns list of editable parameters."""
         return DEVICE_PARAMS
 
-    def __str__(self) -> str:
-        """Converts device instance to a string."""
-        return f"""
-Product:        {self.product}
-Software Ver.:  {self.software}
-UID:            {self.uid}
-Password:       {self.password}
-
-{super().__str__()}
-
-Mixers:
-{self.mixers}
-""".strip()
-
 
 class EcoMAX(Device):
     """ecoMAX device representation.
